@@ -2,7 +2,7 @@
 use crate::project_layout::ProjectLayout;
 use crate::target::Os;
 use crate::{
-    pyproject_toml::Format, BridgeModel, Metadata23, PyProjectToml, PythonInterpreter, Target,
+    pyproject_toml::Format, BridgeModel, Metadata24, PyProjectToml, PythonInterpreter, Target,
 };
 use anyhow::{anyhow, bail, Context, Result};
 use base64::engine::general_purpose::URL_SAFE_NO_PAD;
@@ -143,10 +143,10 @@ impl PathWriter {
     }
 
     /// Writes the RECORD file after everything else has been written
-    pub fn write_record(self, metadata23: &Metadata23) -> Result<()> {
+    pub fn write_record(self, metadata24: &Metadata24) -> Result<()> {
         let record_file = self
             .base_path
-            .join(metadata23.get_dist_info_dir())
+            .join(metadata24.get_dist_info_dir())
             .join("RECORD");
         let mut buffer = File::create(&record_file).context(format!(
             "Failed to create a file at {}",
@@ -295,14 +295,14 @@ impl WheelWriter {
     pub fn new(
         tag: &str,
         wheel_dir: &Path,
-        metadata23: &Metadata23,
+        metadata24: &Metadata24,
         tags: &[String],
         excludes: Override,
     ) -> Result<WheelWriter> {
         let wheel_path = wheel_dir.join(format!(
             "{}-{}-{}.whl",
-            metadata23.get_distribution_escaped(),
-            metadata23.get_version_escaped(),
+            metadata24.get_distribution_escaped(),
+            metadata24.get_version_escaped(),
             tag
         ));
 
@@ -311,13 +311,13 @@ impl WheelWriter {
         let mut builder = WheelWriter {
             zip: ZipWriter::new(file),
             record: Vec::new(),
-            record_file: metadata23.get_dist_info_dir().join("RECORD"),
+            record_file: metadata24.get_dist_info_dir().join("RECORD"),
             wheel_path,
             file_tracker: FileTracker::default(),
             excludes,
         };
 
-        write_dist_info(&mut builder, metadata23, tags)?;
+        write_dist_info(&mut builder, metadata24, tags)?;
 
         Ok(builder)
     }
@@ -326,7 +326,7 @@ impl WheelWriter {
     pub fn add_pth(
         &mut self,
         project_layout: &ProjectLayout,
-        metadata23: &Metadata23,
+        metadata24: &Metadata24,
     ) -> Result<()> {
         if project_layout.python_module.is_some() || !project_layout.python_packages.is_empty() {
             let absolute_path = project_layout
@@ -340,7 +340,7 @@ impl WheelWriter {
                 })?
                 .into_path_buf();
             if let Some(python_path) = absolute_path.to_str() {
-                let name = metadata23.get_distribution_escaped();
+                let name = metadata24.get_distribution_escaped();
                 let target = format!("{name}.pth");
                 debug!("Adding {} from {}", target, python_path);
                 self.add_bytes(target, None, python_path.as_bytes())?;
@@ -473,7 +473,7 @@ impl SDistWriter {
     /// Create a source distribution .tar.gz which can be subsequently expanded
     pub fn new(
         wheel_dir: impl AsRef<Path>,
-        metadata23: &Metadata23,
+        metadata24: &Metadata24,
         excludes: Override,
     ) -> Result<Self, io::Error> {
         let path = wheel_dir
@@ -481,8 +481,8 @@ impl SDistWriter {
             .normalize()?
             .join(format!(
                 "{}-{}.tar.gz",
-                &metadata23.get_distribution_escaped(),
-                &metadata23.get_version_escaped()
+                &metadata24.get_distribution_escaped(),
+                &metadata24.get_version_escaped()
             ))
             .into_path_buf();
 
@@ -597,14 +597,14 @@ fn entry_points_txt(
 }
 
 /// Glue code that exposes `lib`.
-fn cffi_init_file(extension_name: &str) -> String {
+fn cffi_init_file(cffi_module_file_name: &str) -> String {
     format!(
         r#"__all__ = ["lib", "ffi"]
 
 import os
 from .ffi import ffi
 
-lib = ffi.dlopen(os.path.join(os.path.dirname(__file__), '{extension_name}.so'))
+lib = ffi.dlopen(os.path.join(os.path.dirname(__file__), '{cffi_module_file_name}'))
 del os
 "#
     )
@@ -882,6 +882,7 @@ if hasattr({ext_name}, "__all__"):
 #[allow(clippy::too_many_arguments)]
 pub fn write_cffi_module(
     writer: &mut impl ModuleWriter,
+    target: &Target,
     project_layout: &ProjectLayout,
     crate_dir: &Path,
     target_dir: &Path,
@@ -898,22 +899,28 @@ pub fn write_cffi_module(
             .context("Failed to add the python module to the package")?;
     }
 
+    let cffi_module_file_name = {
+        let extension_name = &project_layout.extension_name;
+        // https://cffi.readthedocs.io/en/stable/embedding.html#issues-about-using-the-so
+        match target.target_os() {
+            Os::Macos => format!("lib{extension_name}.dylib"),
+            Os::Windows => format!("{extension_name}.dll"),
+            _ => format!("lib{extension_name}.so"),
+        }
+    };
     let module;
     if let Some(python_module) = &project_layout.python_module {
         if editable {
             let base_path = python_module.join(&project_layout.extension_name);
             fs::create_dir_all(&base_path)?;
-            let target = base_path.join(format!(
-                "{extension_name}.so",
-                extension_name = &project_layout.extension_name
-            ));
+            let target = base_path.join(&cffi_module_file_name);
             fs::copy(artifact, &target).context(format!(
                 "Failed to copy {} to {}",
                 artifact.display(),
                 target.display()
             ))?;
             File::create(base_path.join("__init__.py"))?
-                .write_all(cffi_init_file(&project_layout.extension_name).as_bytes())?;
+                .write_all(cffi_init_file(&cffi_module_file_name).as_bytes())?;
             File::create(base_path.join("ffi.py"))?.write_all(cffi_declarations.as_bytes())?;
         }
 
@@ -942,17 +949,10 @@ pub fn write_cffi_module(
         writer.add_bytes(
             module.join("__init__.py"),
             None,
-            cffi_init_file(&project_layout.extension_name).as_bytes(),
+            cffi_init_file(&cffi_module_file_name).as_bytes(),
         )?;
         writer.add_bytes(module.join("ffi.py"), None, cffi_declarations.as_bytes())?;
-        writer.add_file_with_permissions(
-            module.join(format!(
-                "{extension_name}.so",
-                extension_name = &project_layout.extension_name
-            )),
-            artifact,
-            0o755,
-        )?;
+        writer.add_file_with_permissions(module.join(&cffi_module_file_name), artifact, 0o755)?;
     }
 
     Ok(())
@@ -1231,7 +1231,7 @@ pub fn write_uniffi_module(
 pub fn write_bin(
     writer: &mut impl ModuleWriter,
     artifact: &Path,
-    metadata: &Metadata23,
+    metadata: &Metadata24,
     bin_name: &str,
 ) -> Result<()> {
     let data_dir = PathBuf::from(format!(
@@ -1253,7 +1253,7 @@ pub fn write_bin(
 /// Note that the wasm binary needs to be written separately by [write_bin]
 pub fn write_wasm_launcher(
     writer: &mut impl ModuleWriter,
-    metadata: &Metadata23,
+    metadata: &Metadata24,
     bin_name: &str,
 ) -> Result<()> {
     let entrypoint_script = format!(
@@ -1390,17 +1390,17 @@ pub fn write_python_part(
 /// Creates the .dist-info directory and fills it with all metadata files except RECORD
 pub fn write_dist_info(
     writer: &mut impl ModuleWriter,
-    metadata23: &Metadata23,
+    metadata24: &Metadata24,
     tags: &[String],
 ) -> Result<()> {
-    let dist_info_dir = metadata23.get_dist_info_dir();
+    let dist_info_dir = metadata24.get_dist_info_dir();
 
     writer.add_directory(&dist_info_dir)?;
 
     writer.add_bytes(
         dist_info_dir.join("METADATA"),
         None,
-        metadata23.to_file_contents()?.as_bytes(),
+        metadata24.to_file_contents()?.as_bytes(),
     )?;
 
     writer.add_bytes(
@@ -1410,13 +1410,13 @@ pub fn write_dist_info(
     )?;
 
     let mut entry_points = String::new();
-    if !metadata23.scripts.is_empty() {
-        entry_points.push_str(&entry_points_txt("console_scripts", &metadata23.scripts));
+    if !metadata24.scripts.is_empty() {
+        entry_points.push_str(&entry_points_txt("console_scripts", &metadata24.scripts));
     }
-    if !metadata23.gui_scripts.is_empty() {
-        entry_points.push_str(&entry_points_txt("gui_scripts", &metadata23.gui_scripts));
+    if !metadata24.gui_scripts.is_empty() {
+        entry_points.push_str(&entry_points_txt("gui_scripts", &metadata24.gui_scripts));
     }
-    for (entry_type, scripts) in &metadata23.entry_points {
+    for (entry_type, scripts) in &metadata24.entry_points {
         entry_points.push_str(&entry_points_txt(entry_type, scripts));
     }
     if !entry_points.is_empty() {
@@ -1427,10 +1427,10 @@ pub fn write_dist_info(
         )?;
     }
 
-    if !metadata23.license_files.is_empty() {
+    if !metadata24.license_files.is_empty() {
         let license_files_dir = dist_info_dir.join("licenses");
         writer.add_directory(&license_files_dir)?;
-        for path in &metadata23.license_files {
+        for path in &metadata24.license_files {
             let filename = path.file_name().with_context(|| {
                 format!("missing file name for license file {}", path.display())
             })?;
@@ -1511,7 +1511,7 @@ mod tests {
     #[test]
     // The mechanism is the same for wheel_writer
     fn sdist_writer_excludes() -> Result<(), Box<dyn std::error::Error>> {
-        let metadata = Metadata23::new("dummy".to_string(), Version::new([1, 0]));
+        let metadata = Metadata24::new("dummy".to_string(), Version::new([1, 0]));
         let perm = 0o777;
 
         // No excludes
